#! /bin/bash
#
# install script für mini-sk am Server
#
##################################################################

pfad="/home/samba/progs/minisk/"
pfad2="/home/samba/progs/mausdienst/"
pfad3="/home/samba/progs/maus2/"
etcpfad="/etc/linuxmuster/maus/"
sbinpfad="/usr/sbin/"
initpfad="/etc/init.d/"

##################################################################

if [ "$(id -u)" != "0" ]; then
   echo "###################################"
   echo "# This script must be run as root #"
   echo "###################################"
   exit 1
fi

apt-get -y install openssl apg

mkdir -p $pfad
mkdir -p $pfad2
mkdir -p $pfad3
mkdir -p $etcpfad


if [ -e "$pfad"md.pass ]; then
   echo "#####################################################################"
   echo "# ACHTUNG!                                                          #"
   echo "# Das md-Passwort md.pass existiert schon, es wird beibehalten.     #"
   echo "# Ein neues Passwort liegt nun unter md.pass.neu. und md.md5.neu    #"
   echo "# Ggf. das bisherige Passwort und md5-Datei umbenennen und ersetzen.#"
   echo "#####################################################################"
   apg -n 1 -m 16 -M c | tr -d "\n" > "$pfad"md.pass.neu
   md5sum "$pfad"md.pass.neu | awk -F" " '{print $1}' > "$pfad2"md.md5.neu
else
   echo "md-Passwort wird erzeugt ..."
   apg -n 1 -m 16 -M c | tr -d "\n" > "$pfad"md.pass
   md5sum "$pfad"md.pass | awk -F" " '{print $1}' > "$pfad2"md.md5
fi

openssl genrsa -out "$pfad2"md.key 2048
openssl req -x509 -new -nodes -subj "/C=DE/ST=BW/L=Schule/O=Mausdienst/CN=Mausdienst" -extensions v3_ca -key "$pfad2"md.key -days 3650 -out "$pfad2"md.cert -sha512

echo "Dateien werden zum Server kopiert ..."

if [ -e "$pfad"mini_sk.cfg ]; then
   echo "#############################################################################"
   echo "# ACHTUNG!                                                                  #"
   echo "# Die Konfigurationsdatei mini_sk.cfg existiert schon, sie wird beibehalten.#"
   echo "# Eine neue Konfigurationsdatei liegt nun unter mini_sk.cfg.neu.            #"
   echo "# Ggf. die bisherige Konfigurationsdatei entsprechend anpassen.             #"
   echo "#############################################################################"
   cp mini_sk.cfg "$pfad"mini_sk.cfg.neu
else
   cp mini_sk.cfg $pfad
fi

cp mini_sk $pfad
cp mini_sk.exe $pfad
cp mini_sk.ico $pfad
cp mini_sk.desktop $pfad
cp install-ubuntu-client.sh $pfad
cp openssl.64/libeay32.dll $pfad
cp openssl.64/ssleay32.dll $pfad

cp mausdaemon $pfad2
cp mausdaemon.sh $pfad2
cp mausdaemon.cfg $pfad2
cp sperren.sh $pfad2
cp freigeben.sh $pfad2
cp nachricht.sh $pfad2
cp befehl.sh $pfad2
cp closed.xbm $pfad2

cp mausdienst.exe $pfad2
cp mausdienst.cfg $pfad2
cp openssl.32/libeay32.dll $pfad2
cp openssl.32/ssleay32.dll $pfad2
cp winKeyLockHook.dll $pfad2

cp startmaus $pfad3
cp maus.exe $pfad3
cp "$pfad"md.pass $pfad3
if [ -e "$pfad"md.pass.neu ]; then
  cp "$pfad"md.pass.neu $pfad3
fi
touch "$pfad3"x11vnc.text
if [ -e "$pfad3"maus.cfg ]; then
   echo "############################################################################"
   echo "# ACHTUNG!                                                                 #"
   echo "# Die Konfigurationsdatei maus.cfg existiert schon, sie wird beibehalten.  #"
   echo "# Eine neue Konfigurationsdatei liegt nun unter maus.cfg.neu.              #"
   echo "# Ggf. die bisherige Konfigurationsdatei entsprechend anpassen.            #"
   echo "############################################################################"
   cp maus.cfg "$pfad3"maus.cfg.neu
else
   cp maus.cfg $pfad3
fi

cp maus.ico $pfad3
cp maus.desktop $pfad3
cp wol.exe $pfad3
cp openssl.64/libeay32.dll $pfad3
cp openssl.64/ssleay32.dll $pfad3

echo "Zugriffsrechte werden gesetzt ..."

chown -R pgmadmin:teachers $pfad $pfad2 $pfad3
chmod -R 750 $pfad $pfad2 $pfad3
chmod 640 "$pfad"mini_sk.cfg "$pfad"md.pass "$pfad"mini_sk.ico
chmod 640 "$pfad2"mausdienst.cfg "$pfad2"mausdaemon.cfg "$pfad2"md.md5
chmod 640 "$pfad3"x11vnc.text "$pfad3"maus.cfg "$pfad3"md.pass

if [ -e "$etcpfad"schukodaemon.cfg ]; then
   echo "############################################################################"
   echo "# ACHTUNG!                                                                 #"
   echo "# Die Konfigurationsdatei schukodaemon.cfg ex. schon, sie wird beibehalten.#"
   echo "# Eine neue Konfigurationsdatei liegt nun unter schukodaemon.cfg.neu.      #"
   echo "# Ggf. die bisherige Konfigurationsdatei entsprechend anpassen.            #"
   echo "############################################################################"
   cp schukodaemon.cfg "$etcpfad"schukodaemon.cfg.neu
else
   cp schukodaemon.cfg $etcpfad
   chmod 640 "$etcpfad"schukodaemon.cfg
fi

echo "Prozesse schukodaemon stop ..."
killall -e -9 schukodaemon
sleep 2

openssl genrsa -out "$etcpfad"sk.key 2048
openssl req -x509 -new -nodes -subj "/C=DE/ST=BW/L=Schule/O=schukodaemon/CN=schukodaemon" -extensions v3_ca -key "$etcpfad"sk.key -days 3650 -out "$etcpfad"sk.cert -sha512

echo "Firewall wird konfiguriert ..."

sed -i '/[^0-9]9731/ !s/^tcp .*/&,9731/' /etc/linuxmuster/allowed_ports
restart-fw --int

cp schukodaemon $sbinpfad
cp schukodaemon.sh $initpfad

chown root:root "$sbinpfad"schukodaemon "$initpfad"schukodaemon.sh
chmod 755 "$sbinpfad"schukodaemon "$initpfad"schukodaemon.sh

echo "Boot-Script wird aktiviert ..."

/usr/sbin/update-rc.d schukodaemon.sh defaults

"$initpfad"schukodaemon.sh start

echo "### Installation mini_sk, MAus und schukodaemon beendet ###"

exit 0
